=======
Credits
=======

Development Lead
----------------

Karl Segl <segl@gfz-potsdam.de>

Contributors
------------

* Daniel Scheffler <danschef@gfz-potsdam.de>
  (main developer of the EnPT source code)
* Niklas Bohn <nbohn@gfz-potsdam.de>
  (main developer of the SICOR atmospheric correction source code)
* André Hollstein
* Stéphane Guillaso
* Brenner Silva
